package com.muyu.market.admain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.muyu.common.core.annotation.Excel;
import com.muyu.common.core.web.domain.BaseEntity;
import com.muyu.market.admain.request.ProductSaveReq;
import com.muyu.market.admain.request.ProductUpdReq;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

import java.math.BigDecimal;
import java.util.Date;
import java.util.function.Supplier;

@Data
@SuperBuilder
@AllArgsConstructor
@NoArgsConstructor
@TableName(value = "product",autoResultMap = true)
@EqualsAndHashCode(callSuper = true)
public class Product extends BaseEntity {


    /**
     * 商品ID
     */
    @TableId(value = "productId",type = IdType.AUTO)
    private Long productId;
    /**
     * 商品名称
     */
    @Excel(name = "商品名称")
    private String productName;
    /**
     * 商品价格
     */
    @Excel(name = "商品价格")
    private BigDecimal productPrice;
    /**
     * 库存数量
     */
    @Excel(name = "库存数量")
    private String stock;
    /**
     * 商品描述
     */
    @Excel(name = "商品描述")
    private String description;
    /**
     * 商品状态（1: 在售, 0: 下架）
     */
    @Excel(name = "商品状态（1: 在售, 0: 下架）")
    private String status;
    /**
     * 创建时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Schema(description = "创建时间",defaultValue = "2024-8-15 10:00:57",type = "Date")
    private Date createTime;
    /**
     * 更新时间
     */
   @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
   @Schema(description = "更新时间",defaultValue = "2024-5-15 10:00:52",type = "Date")
    private Date updateTime;

    public static Product SaveProductList(ProductSaveReq productSave){

        return Product
                .builder()
                .productName(productSave.getProductName())
                .productPrice(productSave.getProductPrice())
                .stock(productSave.getStock())
                .description(productSave.getDescription())
                .status(productSave.getStatus())
                .createTime(productSave.getCreateTime())
                .updateTime(productSave.getUpdateTime())
                .build();
    }


    public static Product UpdProductList(ProductUpdReq productUpdReq,Supplier<Long> productId){

        return Product
                .builder()
                .productId(productId.get())
                .productName(productUpdReq.getProductName())
                .productPrice(productUpdReq.getProductPrice())
                .stock(productUpdReq.getStock())
                .description(productUpdReq.getDescription())
                .status(productUpdReq.getStatus())
                .createTime(productUpdReq.getCreateTime())
                .updateTime(productUpdReq.getUpdateTime())
                .build();
    }



}
